@@ -3,9 +3,9 @@
  * Widget:    gtkimreg                                                       *
  * Uses:      GTK+1.2, GdkImlib                                              *
  * Purpose:   get user defined coordinates inside an image                   *
- * Author:    Andreas Tille <tillea@rki.de>                                  *
- * Date:      December 11, 1998                                              *
- * Copyright: Andreas Tille, 1998, 1999                                      *
+ * Author:    Andreas Tille <tille@debian.org>
+ * Date:      May 15, 2001                                                   *
+ * Copyright: Andreas Tille, 1998, 1999, 2000, 2001                          *
  * License:   LGPL                                                           *
  *                                                                           *
  *****************************************************************************/
@@ -28,7 +28,7 @@
 
 #include "gtkintl.h"
 
-static void gtk_imreg_class_init     (GtkImRegClass *klass);
+static void gtk_imreg_class_init     (GtkImRegClass *class);
 static void gtk_imreg_init           (GtkImReg *imreg);
 static void gtk_imreg_destroy        (GtkObject *object);
 
@@ -283,6 +283,14 @@ gtk_imreg_init (GtkImReg *imreg)
 
 GtkWidget*
 gtk_imreg_new (const gchar *title, GdkImlibImage *im, gint rw, gint rh, GtkWidget *user_area)
+/* 
+ * --- Parameter: ---
+ * const gchar   *title    : widget title
+ * GdkImlibImage *im       : image to cut or insert into
+ * gint           rw       : width of region to insert
+ * gint           rh       : width of region to insert
+ * GtkWidget     *user_area: user defined widget to insert in the control area
+ */
 {
   GtkImReg     *imreg;
   GtkWidget    *table;
@@ -296,6 +304,7 @@ gtk_imreg_new (const gchar *title, GdkImlibImage *im, gint rw, gint rh, GtkWidge
   g_return_val_if_fail ( im != NULL, NULL );
   g_return_val_if_fail ( im->rgb_width > 0, NULL );
   g_return_val_if_fail ( im->rgb_height > 0, NULL );
+  g_return_val_if_fail ( im->rgb_data , NULL ) ;
   if ( im->rgb_width < rw ) {
     g_warning(unable, width, rw, width, im->rgb_width);
     return NULL;
